@@ -21,7 +21,7 @@ from urllib.parse import urlparse
 
 from cubicweb.predicates import anonymous_user
 from cubicweb.tags import a
-from cubicweb.web.views.basetemplates import LogInTemplate, LoggedOutTemplate
+from cubicweb_web.views.basetemplates import LogInTemplate, LoggedOutTemplate
 
 from cubicweb_saml.utils import retrieve_url_from_client
 
