@@ -18,7 +18,7 @@ from mock import patch
 from pyramid import testing
 
 from cubicweb import ValidationError, NoResultError
-from cubicweb.devtools import testlib
+from cubicweb.devtools import BASE_URL, testlib
 
 from cubicweb_saml.utils import (
     build_base_url,
@@ -45,7 +45,7 @@ class SAMLUtilsTC(_SAMLCommonTC):
     def test_build_base_url(self):
         config = self.vreg.config
 
-        self.assertEqual(build_base_url(config), "http://testing.fr/cubicweb/")
+        self.assertEqual(build_base_url(config), BASE_URL)
 
         config["base-url"] = "http://url.without.backslash"
 
